==> java-squid-2.7-sources.jar: org/sonar/plugins/java/api/tree/ForStatementTree.java <==
/*
 * SonarQube Java
 * Copyright (C) 2012 SonarSource
 * dev@sonar.codehaus.org
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.plugins.java.api.tree;

import com.google.common.annotations.Beta;

import javax.annotation.Nullable;
import java.util.List;

/**
 * 'for' statement.
 *
 * JLS 14.14
 *
 * <pre>
 *   for ( {@link #initializer()} ; {@link #condition()} ; {@link #update()} ) {@link #statement()}
 * </pre>
 *
 * @since Java 1.3
 */
@Beta
public interface ForStatementTree extends StatementTree {

  SyntaxToken forKeyword();

  SyntaxToken openParenToken();

  List<StatementTree> initializer();

  SyntaxToken firstSemicolonToken();

  @Nullable
  ExpressionTree condition();

  SyntaxToken secondSemicolonToken();

  List<StatementTree> update();

  SyntaxToken closeParenToken();

  StatementTree statement();

}

==> java-squid-3.6-sources.jar: org/sonar/plugins/java/api/tree/ForStatementTree.java <==
/*
 * SonarQube Java
 * Copyright (C) 2012 SonarSource
 * sonarqube@googlegroups.com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.plugins.java.api.tree;

import com.google.common.annotations.Beta;

import javax.annotation.Nullable;

/**
 * 'for' statement.
 *
 * JLS 14.14
 *
 * <pre>
 *   for ( {@link #initializer()} ; {@link #condition()} ; {@link #update()} ) {@link #statement()}
 * </pre>
 *
 * @since Java 1.3
 */
@Beta
public interface ForStatementTree extends StatementTree {

  SyntaxToken forKeyword();

  SyntaxToken openParenToken();

  ListTree<StatementTree> initializer();

  SyntaxToken firstSemicolonToken();

  @Nullable
  ExpressionTree condition();

  SyntaxToken secondSemicolonToken();

  ListTree<StatementTree> update();

  SyntaxToken closeParenToken();

  StatementTree statement();

}
